# IamPermission


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Alphanumeric string identifying the permission. | [optional] 
**object** | **str** | The type of the object. | [optional] 
**name** | **str** | Name of the permission. | [optional] 
**description** | **str** | The description of the permission. | [optional] 
**resource_name** | **str** | The name of the resource the operation will be performed on. | [optional] 
**resource_description** | **str** | The description of the resource. | [optional] 
**scope** | **str** | Permissions are either \&quot;service\&quot; level or \&quot;account\&quot; level. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


